@@ -323,12 +323,12 @@ class Install(install_misc.InstallBase):
         cache = Cache()
 
         # Python standard library.
-        re_minimal = re.compile('^python\d+\.\d+-minimal$')
+        re_minimal = re.compile(r'^python\d+\.\d+-minimal$')
         python_installed = sorted([
             pkg[:-8] for pkg in cache.keys()
             if re_minimal.match(pkg) and cache[pkg].is_installed])
         for python in python_installed:
-            re_file = re.compile('^/usr/lib/%s/.*\.py$' % python)
+            re_file = re.compile(r'^/usr/lib/%s/.*\.py$' % python)
             files = [
                 f for f in cache['%s-minimal' % python].installed_files
                 if (re_file.match(f) and
@@ -759,27 +759,6 @@ class Install(install_misc.InstallBase):
         self.db.progress('SET', 5)
         self.db.progress('STOP')
 
-    def get_resume_partition(self):
-        biggest_size = 0
-        biggest_partition = None
-        try:
-            with open('/proc/swaps') as swaps:
-                for line in swaps:
-                    words = line.split()
-                    if words[1] != 'partition':
-                        continue
-                    if not os.path.exists(words[0]):
-                        continue
-                    if words[0].startswith('/dev/zram'):
-                        continue
-                    size = int(words[2])
-                    if size > biggest_size:
-                        biggest_size = size
-                        biggest_partition = words[0]
-        except Exception:
-            return None
-        return biggest_partition
-
     def configure_hardware(self):
         """Reconfigure several hardware-specific packages.
 
@@ -807,29 +786,6 @@ class Install(install_misc.InstallBase):
             script += '-oem'
         misc.execute(script)
 
-        resume = self.get_resume_partition()
-        if resume is not None:
-            resume_uuid = None
-            try:
-                resume_uuid = subprocess.Popen(
-                    ['block-attr', '--uuid', resume],
-                    stdout=subprocess.PIPE,
-                    universal_newlines=True).communicate()[0].rstrip('\n')
-            except OSError:
-                pass
-            if resume_uuid:
-                resume = "UUID=%s" % resume_uuid
-            if os.path.exists(self.target_file('etc/initramfs-tools/conf.d')):
-                configdir = self.target_file('etc/initramfs-tools/conf.d')
-            elif os.path.exists(self.target_file('etc/mkinitramfs/conf.d')):
-                configdir = self.target_file('etc/mkinitramfs/conf.d')
-            else:
-                configdir = None
-            if configdir is not None:
-                resume_path = os.path.join(configdir, 'resume')
-                with open(resume_path, 'w') as configfile:
-                    print("RESUME=%s" % resume, file=configfile)
-
         osextras.unlink_force(self.target_file('etc/popularity-contest.conf'))
         try:
             participate = self.db.get('popularity-contest/participate')
@@ -875,10 +831,6 @@ class Install(install_misc.InstallBase):
                     'ssl-cert']
         arch, subarch = install_misc.archdetect()
 
-        # this postinst installs EFI application and cleans old entries
-        if arch in ('amd64', 'i386') and subarch == 'efi':
-            packages.append('fwupdate')
-
         try:
             for package in packages:
                 install_misc.reconfigure(self.target, package)
@@ -955,7 +907,8 @@ class Install(install_misc.InstallBase):
 
         inst_boot = self.db.get('ubiquity/install_bootloader')
         if inst_boot == 'true' and 'UBIQUITY_NO_BOOTLOADER' not in os.environ:
-            binds = ("/proc", "/sys", "/dev", "/run")
+            binds = ("/proc", "/sys", "/dev", "/run",
+                     "/sys/firmware/efi/efivars")
             for bind in binds:
                 misc.execute('mount', '--bind', bind, self.target + bind)
 
@@ -1446,7 +1399,7 @@ class Install(install_misc.InstallBase):
         arch, subarch = install_misc.archdetect()
 
         if arch in ('amd64', 'i386'):
-            for pkg in ('grub', 'grub-pc', 'grub-efi', 'grub-efi-amd64',
+            for pkg in ('grub', 'grub-efi', 'grub-efi-amd64',
                         'grub-efi-amd64-signed', 'shim-signed', 'mokutil',
                         'lilo'):
                 if pkg not in keep:
